import { createSlice, PayloadAction } from '@reduxjs/toolkit';
import type { RootState } from './store';
import { Edge, Node } from './graphQueryResultSlice';

export type HoverStateI = { [id: string]: any };

export type SelectionStateI =
  | {
      selectionType: 'node';
      contentType: 'data';
      content: Node[];
    }
  | {
      // TODO: other selection types
      selectionType: 'relation';
      contentType: 'data';
      content: Edge[];
    };

export type FocusStateI = {
  focusType: 'schema' | 'query' | 'visualization';
};

// Define the initial state using that type
export type InteractionsType = {
  hover?: HoverStateI;
  selection?: SelectionStateI;
  focus?: FocusStateI;
};

export const initialState: InteractionsType = {
  hover: undefined,
  selection: undefined,
  focus: undefined,
};

export const interactionSlice = createSlice({
  name: 'interaction',
  // `createSlice` will infer the state type from the `initialState` argument
  initialState,
  reducers: {
    addHover: (state, action: PayloadAction<HoverStateI | undefined>) => {
      state.hover = action.payload;
    },
    unSelect: (state) => {
      state.selection = undefined;
    },
    resultSetSelection: (state, action: PayloadAction<Node[]>) => {
      if (action.payload.length === 0) {
        state.selection = undefined;
      } else {
        state.selection = {
          selectionType: 'node',
          contentType: 'data',
          content: action.payload,
        };
      }
    },
    resultSetFocus: (state, action: PayloadAction<FocusStateI | undefined>) => {
      state.focus = action.payload;
    },
  },
});

export const { addHover, unSelect, resultSetSelection, resultSetFocus } = interactionSlice.actions;

export const interactionState = (state: RootState) => state.interaction;
export const selectionState = (state: RootState) => state.interaction.selection;
export const focusState = (state: RootState) => state.interaction.focus;

export default interactionSlice.reducer;
